[![Documentation Status](https://readthedocs.org/projects/peakrdl-ipxact/badge/?version=latest)](http://peakrdl-ipxact.readthedocs.io)
[![build](https://github.com/SystemRDL/PeakRDL-ipxact/workflows/build/badge.svg)](https://github.com/SystemRDL/PeakRDL-ipxact/actions?query=workflow%3Abuild+branch%3Amain)
[![Coverage Status](https://coveralls.io/repos/github/SystemRDL/PeakRDL-ipxact/badge.svg?branch=main)](https://coveralls.io/github/SystemRDL/PeakRDL-ipxact?branch=main)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/peakrdl-ipxact.svg)](https://pypi.org/project/peakrdl-ipxact)

# PeakRDL-ipxact
This package implements IP-XACT import and export for the PeakRDL toolchain.

- **Export:** Convert compiled SystemRDL input into IP-XACT XML
- **Import:** Read an IP-XACT file and import it into the `systemrdl-compiler` namespace

For the command line tool, see the [PeakRDL project](https://peakrdl.readthedocs.io).

## Documentation
See the [PeakRDL-ipxact Documentation](http://peakrdl-ipxact.readthedocs.io) for more details
